@@ -27,7 +27,10 @@ import unittest
 from datetime import timedelta
 from xoutil.aop import weaved
 from xoutil.aop.basic import contextualized, complementor
-from xoutil.compat import range_
+from xoutil.six.moves import range
+
+
+range_ = lambda *args: list(range(*args))
 
 
 def days(self):
