@@ -39,7 +39,7 @@ def main(default=None):
         cmd_name = args[0]
         args = args[1:]
     else:
-        cmd_name = Command.__default_command__ or default or HELP_NAME
+        cmd_name = default or Command.__default_command__ or HELP_NAME
     cmds = Command.registry
     cmd = cmds.get(cmd_name)
     if not cmd:
